@@ -20,6 +20,9 @@ Implementation Notes
   https://github.com/adafruit/circuitpython/releases
 
 """
+# pylint: disable=too-many-arguments, too-many-instance-attributes, too-many-locals
+# pylint: disable=too-many-statements, unused-import, no-member
+# pylint: disable=unused-import, import-outside-toplevel, undefined-variable
 
 try:
     from typing import Union, Tuple
@@ -27,19 +30,15 @@ try:
 except ImportError:
     pass
 import displayio
+from displayio import Group
 import terminalio
 from bitmaptools import draw_line
 from vectorio import Circle
 from ulab import numpy as np
 
 
-__version__ = "0.10.2"
-__repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
-
-
-# pylint: disable=too-many-arguments, too-many-instance-attributes, too-many-locals
-# pylint: disable=too-many-statements
-# pylint: disable=unused-import, import-outside-toplevel, undefined-variable
+__version__ = "0.11.0"
+__repo__ = "https://github.com/jposada202020/CircuitPython_uplot.git"
 
 
 class Uplot(displayio.Group):
@@ -128,12 +127,12 @@ class Uplot(displayio.Group):
 
         self._index_colorused = 4
 
-        self._plotbitmap = displayio.Bitmap(width, height, 14)
+        self._plotbitmap = displayio.Bitmap(width, height, 17)
 
         if show_box:
             self._drawbox()
 
-        self._plot_palette = displayio.Palette(14)
+        self._plot_palette = displayio.Palette(17)
         self._plot_palette[0] = background_color
         self._plot_palette[1] = box_color
         self._plot_palette[2] = self._tickcolor
